@@ -16,9 +16,10 @@ import xlrd
 from PIL import Image
 import qrcode
 from decimal import Decimal, ROUND_HALF_UP, InvalidOperation, DecimalException
+from .crypto import get_nonce
 
 
-__version__ = '2.4'
+__version__ = '2.5.1'
 
 __all__ = [
     'dc_gen_code', 'dc_records_changed', 'start_end_time', 'start_end_time_ex',
@@ -227,18 +228,25 @@ DT_FULL_EX2 = 13  # 年月日_时分秒_毫秒
 class JdTools(object):
     """工具类，实现常用函数"""
     @staticmethod
-    def getdate():
-        """获取当前日期字符串 返回 年-月-日_时分秒 例如：2018-09-21_084800"""
-        date = datetime.datetime.today()
-        data_str = datetime.datetime.strftime(date, '%Y-%m-%d_%H%M%S')
-        return data_str
+    def getdate(no_ms=True, nonce=True):
+        """获取当前日期字符串 返回 年月日_时分秒 例如：20180921_084800_ab67DE
+        :param no_ms:       文件名不带毫秒
+        :param nonce:       文件名是否带随机字符
+        """
+        return JdTools.get_date(no_ms, nonce)
 
     @staticmethod
-    def get_date():
-        """获取当前日期字符串 返回 年-月-日_时分秒毫秒 例如：2018-09-21_084800_458394"""
-        date = datetime.datetime.today()
-        data_str = datetime.datetime.strftime(date, '%Y-%m-%d_%H%M%S_%f')
-        return data_str
+    def get_date(no_ms=True, nonce=True):
+        """获取当前日期字符串 返回 年月日_时分秒_6位随机字符 例如：20180921_084800_ab67DE
+        :param no_ms:       文件名不带毫秒
+        :param nonce:       文件名是否带随机字符
+        """
+        tm = datetime.datetime.today()
+        fmt = '%Y%m%d_%H%M%S' if no_ms else '%Y%m%d_%H%M%S_%f'
+        data_str = datetime.datetime.strftime(tm, fmt)
+        if nonce:
+            return f'{data_str}_{get_nonce(6)}'
+        return f'{data_str}'
 
     @staticmethod
     def trim(s):
@@ -310,19 +318,19 @@ class JdTools(object):
         return operator.eq(x, y)    # Python 3  True or False
 
     @staticmethod
-    def get_filename(name, excel2010=False, no_ext=False, no_ms=False):
+    def get_filename(name, excel2010=False, no_ext=False, no_ms=True, nonce=True):
         """
         返回 唯一 文件名，name 后面增加 年月日_时分秒_毫秒 后缀
         :param name:        文件名前缀
         :param excel2010:   excel文件后缀格式， True-4位后缀文件扩展名， False - xls
         :param no_ext:      不带文件名后缀
         :param no_ms:       文件名不带毫秒
+        :param nonce:       文件名是否带随机字符
         :return:    文件名 name + 日期 + 扩展名
         """
-        tm = datetime.datetime.today()
-        fmt = '_%Y%m%d_%H%M%S' if no_ms else '_%Y%m%d_%H%M%S_%f'
-        time_str = datetime.datetime.strftime(tm, fmt)
-        return name + time_str + ('' if no_ext else ('.xls' + ('x' if excel2010 else '')))
+        time_str = JdTools.get_date(no_ms=no_ms, nonce=nonce)
+        ext = '' if no_ext else ('.xls' + ('x' if excel2010 else ''))
+        return name + time_str + ext
 
     @staticmethod
     def str(val):
